@@ -146,7 +146,7 @@ from_numpy = ('ComplexWarning', 'Inf', 'NAN', 'abs', 'absolute', 'add',
               'take', 'tan', 'tanh', 'tensordot', 'tile', 'trace',
               'transpose', 'trapz', 'tri', 'tril', 'tril_indices',
               'tril_indices_from', 'trim_zeros', 'triu', 'triu_indices',
-              'triu_indices_from', 'true_divide', 'trunc', 'typeDict',
+              'triu_indices_from', 'true_divide', 'trunc',
               'typeNA', 'typename', 'ubyte', 'ufunc', 'uint', 'uint32',
               'union1d', 'unique', 'unique1d', 'unpackbits',
               'unravel_index', 'unsignedinteger', 'unwrap', 'ushort',
