@@ -180,6 +180,8 @@ class DataSourceSpecH5(object):
             how the data are organized in the HDF5 container
             'silx' : default
             'spec2nexus' : as converted by spec2nexus
+        verbose : bool [False]
+            if True it lowers the logger level to INFO, othewise WARNING by default
         """
         if logger is None:
             from larch.utils.logging import getLogger
@@ -190,12 +192,13 @@ class DataSourceSpecH5(object):
             self._logger = logger
 
         if verbose:
-            self._logger.set_level("INFO")
+            self._logger.setLevel("INFO")
 
         self._fname = fname
         self._sourcefile = None
         self._sourcefile_type = None
         self._scans = None
+        self._scans_names = None
         self._scan_n = None
         self._scan_str = None
 
@@ -242,7 +245,16 @@ class DataSourceSpecH5(object):
                 if ft in str(self._sourcefile):
                     self._sourcefile_type = ft
             self._scans = self.get_scans()
-            self.set_scan(self._scans[0][0])  # set the first scan at init
+            self._scans_names = [scn[0] for scn in self._scans]
+            try:
+                _iscn = 0
+                self.set_scan(self._scans[_iscn][0])  # set the first scan at init
+                while len(self.get_counters()) == 1:
+                    self._logger.warning(f"not enough data in scan {_iscn+1} '{self.get_title()}'")
+                    _iscn += 1
+                    self.set_scan(self._scans[_iscn][0])
+            except Exception as e:
+                self._logger.error(e)
         except OSError:
             self._logger.error(f"cannot open {self._fname}")
 
@@ -259,8 +271,16 @@ class DataSourceSpecH5(object):
         self._sourcefile.close()
         self._sourcefile = None
 
-    def get_scangroup(self):
-        """get current scan group"""
+    def get_scangroup(self, scan=None):
+        """get current scan group
+
+        Parameters
+        ----------
+        scan  : str, int, or None
+             scan address
+        """
+        if scan is not None:
+            self.set_scan(scan)        
         if self._scangroup is None:
             raise AttributeError(
                 "Group/Scan not selected -> use 'self.set_scan()' first"
@@ -281,16 +301,16 @@ class DataSourceSpecH5(object):
         none: sets attribute self._group_url
         """
         self._group_url = group_url
-        if self._group_url is not None and self.verbose:
-            self._logger.info(f"Selected group {self._group_url}")
-
-    def set_scan(self, scan_n, scan_idx=1, group_url=None, scan_kws=None):
-        """Select a given scan number
+        if self._group_url is not None:
+            self._logger.info(f"selected group {self._group_url}")
 
+    def set_scan(self, scan, scan_idx=1, group_url=None, scan_kws=None):
+        """Select a given scan
+        
         Parameters
         ----------
-        scan_n : int or str
-            scan number or address
+        scan : int or str
+            scan number or name
         scan_idx : int (optional)
             scan repetition index [1]
         group_url : str
@@ -303,33 +323,37 @@ class DataSourceSpecH5(object):
         none: set attributes
             self._scan_n, self._scan_str, self._scan_url, self._scangroup
         """
-        # check if scan_n is given already as "scan_n.scan_idx"
-        if isinstance(scan_n, str):
-            scan_split = scan_n.split(".")
-            scan_n = scan_split[0]
-            try:
-                scan_idx = scan_split[1]
-            except IndexError:
-                self._logger.warning("'scan_idx' kept at 1")
-                pass
-            try:
-                scan_n = int(scan_n)
-                scan_idx = int(scan_idx)
-            except ValueError:
-                self._logger.error("scan not selected, wrong 'scan_n'!")
-                return
-        assert isinstance(scan_n, int), "'scan_n' must be an integer"
-        assert isinstance(scan_idx, int), "'scan_idx' must be an integer"
-        self._scan_n = scan_n
         if scan_kws is not None:
             self._scan_kws = update_nested(self._scan_kws, scan_kws)
-        if self._urls_fmt == "silx":
-            self._scan_str = f"{scan_n}.{scan_idx}"
-        elif self._urls_fmt == "spec2nexus":
-            self._scan_str = f"S{scan_n}"
+        if scan in self._scans_names:
+            self._scan_str = scan
+            self._scan_n = self._scans_names.index(scan)
         else:
-            self._logger.error("wrong 'urls_fmt'")
-            return
+            scan_n = scan
+            if isinstance(scan, str):
+                scan_split = scan.split(".")
+                scan_n = scan_split[0]
+                try:
+                    scan_idx = scan_split[1]
+                except IndexError:
+                    self._logger.warning("'scan_idx' kept at 1")
+                    pass
+                try:
+                    scan_n = int(scan_n)
+                    scan_idx = int(scan_idx)
+                except ValueError:
+                    self._logger.error("scan not selected, wrong 'scan' parameter!")
+                    return
+            assert isinstance(scan_n, int), "'scan_n' must be an integer"
+            assert isinstance(scan_idx, int), "'scan_idx' must be an integer"
+            self._scan_n = scan_n
+            if self._urls_fmt == "silx":
+                self._scan_str = f"{scan_n}.{scan_idx}"
+            elif self._urls_fmt == "spec2nexus":
+                self._scan_str = f"S{scan_n}"
+            else:
+                self._logger.error("wrong 'urls_fmt'")
+                return
         if group_url is not None:
             self.set_group(group_url)
         if self._group_url is not None:
@@ -341,13 +365,14 @@ class DataSourceSpecH5(object):
             self._scan_title = self.get_title()
             self._scan_start = self.get_time()
             self._logger.info(
-                f"selected scan {self._scan_url}: '{self._scan_title}' ({self._scan_start})"
+                f"selected scan '{self._scan_url}' | '{self._scan_title}' | '{self._scan_start}'"
             )
         except KeyError:
             self._scangroup = None
             self._scan_title = None
             self._logger.error(f"'{self._scan_url}' is not valid")
 
+
     def _list_from_url(self, url_str):
         """Utility method to get a list from a scan url
 
@@ -392,13 +417,31 @@ class DataSourceSpecH5(object):
         allscans = []
         for sn in self._sourcefile["/"].keys():
             sg = self._sourcefile[sn]
-            allscans.append(
-                [
-                    sn,
-                    bytes2str(sg[self._title_url][()]),
-                    bytes2str(sg[self._time_start_url][()]),
-                ]
-            )
+            try:
+                allscans.append(
+                    [
+                        sn,
+                        bytes2str(sg[self._title_url][()]),
+                        bytes2str(sg[self._time_start_url][()]),
+                    ]
+                )
+            except KeyError:
+                self._logger.error(f"'{sn}' is a datagroup!")
+                #go one level below and try take first dataset only
+                dt0 = list(sg.keys())[0]
+                sgg = sg[dt0]
+                try:
+                    scname = f"{sn}/{dt0}"
+                    allscans.append(
+                        [
+                            scname,
+                            bytes2str(sgg[self._title_url][()]),
+                            bytes2str(sgg[self._time_start_url][()]),
+                        ]
+                    )
+                except Exception:
+                    self._logger.error(f"{scname} does not have standard title/time URLs")
+                    allscans.append([None, None, None])
         return allscans
 
     def get_motors(self):
@@ -455,7 +498,7 @@ class DataSourceSpecH5(object):
 
         Known types of scans
         --------------------
-        'ascan'/'dscan'
+        Generic: <scan_type> <scan_axis> <start> <end> <npoints> <counting_time>
         'Escan' (ESRF-BM30/BM16)
         'Emiscan' (ESRF-BM30/BM16)
         'fscan' (ESRF-ID26)
@@ -485,22 +528,9 @@ class DataSourceSpecH5(object):
         if isinstance(_title, np.ndarray):
             _title = np.char.decode(_title)[0]
         _title_splitted = [s for s in _title.split(" ") if not s == ""]
-        _iax = 0
-        _scntype = _title_splitted[_iax]
+        _scntype = _title_splitted[0]
+        iscn.update(dict(scan_type=_scntype))
         try:
-            iscn.update(
-                dict(
-                    scan_type=_scntype,
-                    scan_start=_title_splitted[1],
-                    scan_end=_title_splitted[2],
-                    scan_pts=_title_splitted[3],
-                    scan_ct=_title_splitted[4],
-                )
-            )
-        except IndexError:
-            pass
-
-        if _scntype in ("ascan", "dscan"):
             iscn.update(
                 dict(
                     scan_axis=_title_splitted[1],
@@ -510,6 +540,19 @@ class DataSourceSpecH5(object):
                     scan_ct=_title_splitted[5],
                 )
             )
+        except IndexError:
+            try:
+                iscn.update(
+                    dict(
+                        scan_start=_title_splitted[1],
+                        scan_end=_title_splitted[2],
+                        scan_pts=_title_splitted[3],
+                        scan_ct=_title_splitted[4],
+                    )
+                )
+            except IndexError:
+                pass
+
         if _scntype == "Escan":
             iscn.update(dict(scan_axis="Energy"))
         if _scntype == "Emiscan":
@@ -580,14 +623,19 @@ class DataSourceSpecH5(object):
             self._logger.error(f"'{mot}' not found in available motors: {mots}")
             return None
 
-    def get_scan(self):
+    def get_scan(self, scan=None):
         """Get Larch group for the current scan
 
+        Parameters
+        ----------
+        scan  : str, int, or None
+             scan address 
+
         Returns
         -------
         larch Group with scan data
         """
-        scan_group = self.get_scangroup()
+        scan_group = self.get_scangroup(scan)
         scan_index = self._scan_n
         scan_name = self._scan_str
         all_labels = self.get_counters()
@@ -637,7 +685,8 @@ class DataSourceSpecH5(object):
                 self._logger.warning(
                     f"'{label}' skipped (shape is different from '{axis}')"
                 )
-                array_labels.pop(label)
+                ipop = array_labels.index(label)
+                array_labels.pop(ipop)
         out.data = np.array(data)
         return out
 
@@ -757,6 +806,4 @@ def open_specfile(filename):
 def read_specfile(filename, scan=None):
     """simple mapping of a Spec/BLISS file to a Larch group"""
     df = DataSourceSpecH5(filename)
-    if scan is not None:
-        df.set_scan(scan)
-    return df.get_scan()
+    return df.get_scan(scan)
