@@ -26,7 +26,7 @@ from larch import Group, site_config
 from larch.math import index_of
 from larch.fitting import group2params, param
 from larch.utils.jsonutils import encode4js, decode4js
-from larch.utils.strutils import fix_varname
+from larch.utils.strutils import fix_varname, fix_filename
 from larch.io.export_modelresult import export_modelresult
 from larch.xafs import feffit_report
 from larch.wxlib import (ReportFrame, BitmapButton, FloatCtrl, FloatSpin,
@@ -134,8 +134,8 @@ if len(_ff2chi_paths) > 0:
 COMMANDS['do_feffit'] = """# build feffit dataset, run feffit
 _feffit_dataset = feffit_dataset(data={groupname:s}, transform={trans:s}, paths={paths:s})
 _feffit_result = feffit({params}, _feffit_dataset)
-
 if not hasattr({groupname:s}, 'feffit_history'): {groupname}.feffit_history = []
+_feffit_result.label = 'Fit %i' % (1+len({groupname}.feffit_history))
 {groupname:s}.feffit_history.insert(0, _feffit_result)
 """
 
@@ -267,11 +267,13 @@ class EditParamsFrame(wx.Frame):
         toppan.Add(Button(toppan, "Remove Selected",   action=self.onRemove, size=(175,-1)), newrow=True)
         toppan.Add(Button(toppan, "'Fix' Selected",    action=self.onFix, size=(175, -1)))
         toppan.Add(Button(toppan, "Force Refresh",     action=self.onRefresh, size=(200, -1)))
-        npan = wx.Panel(self)
+        npan = wx.Panel(toppan)
         nsiz = wx.BoxSizer(wx.HORIZONTAL)
 
-        self.par_name = wx.TextCtrl(npan, value='<name>', size=(125, -1))
-        self.par_expr = wx.TextCtrl(npan, value='<expression or value>', size=(250, -1))
+        self.par_name = wx.TextCtrl(npan, -1, value='par_name', size=(125, -1),
+                                    style=wx.TE_PROCESS_ENTER)
+        self.par_expr = wx.TextCtrl(npan, -1, value='<expression or value>', size=(250, -1),
+                                    style=wx.TE_PROCESS_ENTER)
         nsiz.Add(SimpleText(npan, "Add Parameter:"), 0)
         nsiz.Add(self.par_name, 0)
         nsiz.Add(self.par_expr, 1, wx.GROW|wx.ALL)
@@ -1032,6 +1034,8 @@ class FeffitPanel(TaskPanel):
         atoms.pop(0)
         atoms.pop()
         title = '_'.join(atoms) + "%d" % (round(100*pathinfo.reff))
+        for c in ',.[](){}<>+=-?/\\&%$#@!|:;"\'':
+            title = title.replace(c, '')
         if title in self.paths_data:
             btitle = title
             i = -1
@@ -1323,7 +1327,7 @@ class FeffitResultFrame(wx.Frame):
     def __init__(self, parent=None, feffit_panel=None, datagroup=None,
                   **kws):
         wx.Frame.__init__(self, None, -1, title='Feffit Results',
-                          style=FRAMESTYLE, size=(850, 700), **kws)
+                          style=FRAMESTYLE, size=(900, 700), **kws)
 
         self.outforms = {'chik': 'chi(k), no k-weight',
                          'chikw': 'chi(k), k-weighted',
@@ -1402,6 +1406,11 @@ class FeffitResultFrame(wx.Frame):
         wids['show_script']  = Button(panel,'Show Feffit Script',
                                         action=self.onShowScript, size=(175, -1))
 
+        wids['fit_label'] = wx.TextCtrl(panel, -1, ' ', size=(225, -1))
+        wids['set_label'] = Button(panel, 'Update Label', size=(175, -1),
+                                   action=self.onUpdateLabel)        
+   
+        
         irow = 0
         sizer.Add(title,              (irow, 0), (1, 1), LEFT)
         sizer.Add(wids['data_title'], (irow, 1), (1, 3), LEFT)
@@ -1424,10 +1433,16 @@ class FeffitResultFrame(wx.Frame):
         irow += 1
         sizer.Add(HLine(panel, size=(650, 3)), (irow, 0), (1, 5), LEFT)
 
+        irow += 1
+        sizer.Add(SimpleText(panel, 'Fit Label:', style=LEFT), (irow, 0), (1, 1), LEFT)
+        sizer.Add(wids['fit_label'], (irow, 1), (1, 2), LEFT)
+        sizer.Add(wids['set_label'], (irow, 3), (1, 1), LEFT)
+        
+
         irow += 1
         title = SimpleText(panel, '[[Fit Statistics]]',  font=Font(FONTSIZE+2),
                            colour=self.colors.title, style=LEFT)
-        subtitle = SimpleText(panel, '  (Fit #01 is most recent)',
+        subtitle = SimpleText(panel, ' (most recent fit is at the top)',
                               font=Font(FONTSIZE+1),  style=LEFT)
 
         sizer.Add(title, (irow, 0), (1, 1), LEFT)
@@ -1435,14 +1450,15 @@ class FeffitResultFrame(wx.Frame):
 
         sview = self.wids['stats'] = dv.DataViewListCtrl(panel, style=DVSTYLE)
         sview.Bind(dv.EVT_DATAVIEW_SELECTION_CHANGED, self.onSelectFit)
-        sview.AppendTextColumn(' Fit#',   width=65)
-        sview.AppendTextColumn(' N_data', width=65)
-        sview.AppendTextColumn(' N_vary', width=65)
-        sview.AppendTextColumn(' N_idp',  width=75)
-        sview.AppendTextColumn('\u03c7\u00B2', width=85)
-        sview.AppendTextColumn('reduced \u03c7\u00B2', width=110)
+        sview.AppendTextColumn(' Label', width=120)
+        sview.AppendTextColumn('N_paths', width=75)
+        sview.AppendTextColumn('N_vary', width=70)
+        sview.AppendTextColumn('N_idp',  width=70)
+        sview.AppendTextColumn('\u03c7\u00B2', width=80)
+        sview.AppendTextColumn('reduced \u03c7\u00B2', width=90)
+        sview.AppendTextColumn('R Factor', width=90)
         sview.AppendTextColumn('Akaike Info', width=95)
-        sview.AppendTextColumn('Bayesian Info', width=95)
+
 
         for col in range(sview.ColumnCount):
             this = sview.Columns[col]
@@ -1464,7 +1480,7 @@ class FeffitResultFrame(wx.Frame):
         sizer.Add(title, (irow, 0), (1, 1), LEFT)
 
         self.wids['copy_params'] = Button(panel, 'Update Model with these values',
-                                          size=(250, -1), action=self.onCopyParams)
+                                          size=(225, -1), action=self.onCopyParams)
 
         sizer.Add(self.wids['copy_params'], (irow, 1), (1, 3), LEFT)
 
@@ -1555,19 +1571,28 @@ class FeffitResultFrame(wx.Frame):
 
     def onShowPathParams(self, event=None):
         result = self.get_fitresult()
-        text  = feffit_report(result)
-        title = f'Report for {self.datagroup.filename} fit #{1+self.nfit:d}'
-        fname = f'{self.datagroup.filename}_fit{self.nfit:d}.txt'
+        text = f'# Feffit Report for {self.datagroup.filename} fit "{result.label}"\n'
+        text = text + feffit_report(result)
+        title = f'Report for {self.datagroup.filename} fit "{result.label}"'
+        fname = fix_filename(f'{self.datagroup.filename}_{result.label}.txt')
         self.show_report(text, title=title, default_filename=fname)
 
     def onShowScript(self, event=None):
         result = self.get_fitresult()
-        text  = '\n'.join(result.commands)
-        title = f'Script for {self.datagroup.filename} fit #{1+self.nfit:d}'
-        fname = f'{self.datagroup.filename}_fit{self.nfit:d}.lar'
+        text = [f'# Feffit Script for {self.datagroup.filename} fit "{result.label}"']                
+        text.extend(result.commands)
+        text = '\n'.join(text)
+        title = f'Script for {self.datagroup.filename} fit "{result.label}"'
+        fname = fix_filename(f'{self.datagroup.filename}_{result.label}.lar')
         self.show_report(text, title=title, default_filename=fname,
                          wildcard='Larch/Python Script (*.lar)|*.lar')
 
+    def onUpdateLabel(self, event=None):
+        result = self.get_fitresult()
+        item = self.wids['stats'].GetSelectedRow()
+        result.label = self.wids['fit_label'].GetValue()
+        self.show_results()
+
     def onPlot(self, event=None):
         opts = {'build_fitmodel': False}
         for key, meth in (('plot_ftwindows', 'IsChecked'),
@@ -1582,11 +1607,12 @@ class FeffitResultFrame(wx.Frame):
         trans  = result.datasets[0].transform
 
         result_name  = f'{self.datagroup.groupname}.feffit_history[{self.nfit}]'
+        opts['label'] = f'{result_name}.label'
         opts['pargroup_name'] = f'{result_name}.paramgroup'
         opts['paths_name']    = f'{result_name}.datasets[0].paths'
         opts['pathsum_name']  = f'{result_name}.datasets[0].model'
         opts['dgroup']  = dgroup
-        opts['title'] = f'{self.datagroup.filename} fit #{self.nfit:d}'
+        opts['title'] = f'{self.datagroup.filename} "{result.label}"'
 
         for attr in ('kmin', 'kmax', 'dk', 'rmin', 'rmax', 'fitspace'):
             opts[attr] = getattr(trans, attr)
@@ -1599,7 +1625,7 @@ class FeffitResultFrame(wx.Frame):
     def onSaveFitCommand(self, event=None):
         wildcard = 'Larch/Python Script (*.lar)|*.lar|All files (*.*)|*.*'
         result = self.get_fitresult()
-        fname = f'{self.datagroup.filename}_fit{self.nfit:d}.lar'
+        fname = fix_filename(f'{self.datagroup.filename}_{result.label:s}.lar')
 
         path = FileSave(self, message='Save text to file',
                         wildcard=wildcard, default_file=fname)
@@ -1612,7 +1638,9 @@ class FeffitResultFrame(wx.Frame):
 
     def onSaveFit(self, evt=None, form='chikw'):
         "Save arrays to text file"
-        fname = f'{self.datagroup.filename}_fit{(1+self.nfit):d}_{form}'
+        result = self.get_fitresult()
+        
+        fname = fix_filename(f'{self.datagroup.filename}_{result.label:s}_{form}')
         fname = fname.replace('.', '_')
         fname = fname + '.txt'
 
@@ -1626,7 +1654,7 @@ class FeffitResultFrame(wx.Frame):
         result = self.get_fitresult()
         text = feffit_report(result)
         desc = self.outforms[form]
-        buff = [f'# Results for {self.datagroup.filename} fit #{1+self.nfit:d}: {desc}']
+        buff = [f'# Results for {self.datagroup.filename} "{result.label}": {desc}']
 
         for line in text.split('\n'):
             buff.append('# %s' % line)
@@ -1763,9 +1791,9 @@ class FeffitResultFrame(wx.Frame):
         wids = self.wids
         wids['stats'].DeleteAllItems()
         for i, res in enumerate(self.fit_history):
-            args = ['%2.2d' % (i+1)]
-            for attr in ('ndata', 'nvarys', 'n_independent', 'chi_square',
-                         'chi2_reduced', 'aic', 'bic'):
+            args = [res.label, "%.d" % (len(res.datasets[0].paths))]
+            for attr in ('nvarys', 'n_independent', 'chi_square',
+                         'chi2_reduced', 'rfactor', 'aic'):
                 val = getattr(res, attr)
                 if isinstance(val, int):
                     val = '%d' % val
@@ -1788,6 +1816,7 @@ class FeffitResultFrame(wx.Frame):
             path_hashkeys.extend([p.hashkey for p in ds.paths.values()])
 
         wids = self.wids
+        wids['fit_label'].SetValue(result.label)
         wids['data_title'].SetLabel(self.datagroup.filename)
         wids['params'].DeleteAllItems()
         wids['paramsdata'] = []
